/* UFPS Anti Advertising 

PURPOSE:
	The plugin is designed to block any recurring advertising messages from players in the chat server, and also for cleaning config players from advertising flooding.


DESCRIPTION OF WORK: 
	- Messaging administrators are not checked. 
	- Messages from the players, containing: a point or a colon and the length boee 8 (in the source file MIN_SAYALERT) characters, 
	as well as all messages more than 32 (in the source file MAX_SAYALERT) 		
	characters - declared suspicious and re-emergence of identical messages blocked. 
	- When the count of suspicious messages exceeds a certain value (default 3 in the source file MIN_VERIFY) after the death of the player displays the menu shown in the screenshot. 
	- When you select 1 player puknta forcibly sent to all the lines starting with antiadvert.ini unbindall a bind. 
	- When selecting 2 points off a team player to disconnect. 

Note: 
	- Starting defined as suspicious and is distinct from other suspicious skipped to chat! 
	- Plugin almost does not load on the server. 
	- It is recommended to have this plug-in pluins.ini above plug-ins, working with chat, such as for example translate.amxx.
*/

#include <amxmodx>
#include <amxmisc>

#define MIN_SAYALERT	8		// The minimum length of the message for verification, containing a point or a colon
#define MAX_SAYALERT	32		// The minimum length of the message to verify
#define MIN_VERIFY		3		// Number of suspicion on advertising, before displaying the menu
#define MAX_RECORDS		32		// Number of records in the database for monitoring
#define LEN_RECORDS		191
#define DEF_CONFIG		128

new pcv_menu

new rec_verify[33]
new rec_counter[33]
new rec_database[33][MAX_RECORDS][LEN_RECORDS+1]

new def_counter
new def_database[DEF_CONFIG][LEN_RECORDS+1]

public plugin_init( )
{
	register_plugin( "UFPS Anti Advertising","2.2","UFPS.Team" )
	register_dictionary( "antiadvert.txt" )

	register_clcmd( "say",      "cmd_handle_say" )
	register_clcmd( "say_team", "cmd_handle_say" )
}

public plugin_cfg()
{
	new configsdir[64], filename[64], string[LEN_RECORDS+1], pos, len

	get_configsdir( configsdir, charsmax( configsdir ) )
	formatex( filename, charsmax( filename ), "%s/antiadvert.ini", configsdir )

	if( file_exists( filename ) )
	{
		while( ( def_counter < DEF_CONFIG ) && read_file( filename, pos++, string, LEN_RECORDS, len ) )
		{
			if( !containi( string, "BIND" ) || !containi( string, "UNBINDALL" ) )
				copy( def_database[def_counter++], LEN_RECORDS, string )
		}
	}

	else
	{
		log_amx( "%s not found", filename )
	}

	pcv_menu = menu_create( "ADV_CLEAR_MENU", "_handle_menu", 1 )
	menu_additem( pcv_menu, "", "1" )
	menu_additem( pcv_menu, "", "2" )
	menu_setprop( pcv_menu, MPROP_NUMBER_COLOR, "\r" )
	menu_setprop( pcv_menu, MPROP_EXIT, MEXIT_NEVER )
}

public cmd_handle_say( id )
{
	if( is_user_admin( id ) ) return PLUGIN_CONTINUE

	static arg[LEN_RECORDS+1]
	read_args( arg, LEN_RECORDS )

	if( ( ( contain( arg, "." ) != -1 || contain( arg, ":" ) != -1 ) && strlen( arg ) > MIN_SAYALERT ) || strlen( arg ) > MAX_SAYALERT )
	{
		if( !add_record( id, arg ) ) return PLUGIN_HANDLED
	}

	return PLUGIN_CONTINUE
}

stock bool:add_record( id, const arg[] )
{
	if( !find_record( id, arg ) )
	{
		if( rec_counter[id] >= MAX_RECORDS ) rec_counter[id] = 0

		copy( rec_database[id][rec_counter[id]], LEN_RECORDS, arg )
		rec_counter[id]++
	}

	else
	{
		rec_verify[id]++
		return false
	}

	return true
}

stock bool:find_record( id, const arg[] )
{
	static i

	for( i = 0; i < rec_counter[id]; i++ )
		if( equal( rec_database[id][i], arg ) ) return true

	return false
}

public client_death( killer, id, wpnindex, hitplace, tk )
{
	if( rec_verify[id] > MIN_VERIFY )
	{
		if( task_exists( id ) ) remove_task( id )

		set_task( 1.0, "_print_menu", id )
	}
}

public _print_menu( id )
{
	if( !is_user_connected( id ) )
		return PLUGIN_HANDLED

	new m_title[256], m_clear[128], m_quit[128]

	formatex( m_title, charsmax( m_title ), "%L", id, "UAA_TITLE" )
	formatex( m_clear, charsmax( m_clear ), "%L", id, "UAA_CLEAR" )
	formatex( m_quit, charsmax( m_quit ), "%L", id, "UAA_QUIT" )

	menu_item_setname( pcv_menu, 0, m_clear )
	menu_item_setname( pcv_menu, 1, m_quit )

	menu_setprop( pcv_menu, MPROP_TITLE, m_title )
	menu_display( id, pcv_menu )

	return PLUGIN_CONTINUE
}

public _handle_menu( id, menu, item )
{
	if( item == MENU_EXIT ) return PLUGIN_HANDLED

	new _access, info[3], callback
	menu_item_getinfo( menu, item, _access, info, charsmax( info ), _, _, callback )

	new key = str_to_num( info )

	switch( key )
	{
		case 1:
		{
			for( new i=0; i < def_counter; ++i )
			{
				client_cmd( id, def_database[i] )
			}

			rec_verify[id] = 0

			new name[32], authid[44]
			get_user_name( id, name, charsmax( name ) )
			get_user_authid( id, authid, charsmax( authid ) )
			log_amx( "Clear config: ^"%s^" <%d> [%s]", name, get_user_userid( id ), authid )
		}

		case 2:
		{
			client_cmd( id, ";disConnect" )
		}
	}

	return PLUGIN_HANDLED
}

public client_disconnect( id )
{
	rec_verify[id] = 0

	if( task_exists( id ) ) remove_task( id )
}

public plugin_end( )
{
	menu_destroy( pcv_menu )
}
